@@ -2,9 +2,9 @@
 # SPDX-License-Identifier: Apache-2.0
 
 import logging
+from typing import Any, Optional
 
-from pyhocon import ConfigTree  # noqa: F401
-from typing import Optional, Any  # noqa: F401
+from pyhocon import ConfigTree
 
 from databuilder.loader.base_loader import Loader
 
@@ -13,13 +13,13 @@ LOGGER = logging.getLogger(__name__)
 CALLBACK_FUNCTION = 'callback_function'
 
 
-def log_call_back(record):
+def log_call_back(record: Optional[Any]) -> None:
     """
     A Sample callback function. Implement any function follows this function's signature to fit your needs.
     :param record:
     :return:
     """
-    LOGGER.info('record: {}'.format(record))
+    LOGGER.info('record: %s', record)
 
 
 class GenericLoader(Loader):
@@ -27,8 +27,7 @@ class GenericLoader(Loader):
     Loader class to call back a function provided by user
     """
 
-    def init(self, conf):
-        # type: (ConfigTree) -> None
+    def init(self, conf: ConfigTree) -> None:
         """
         Initialize file handlers from conf
         :param conf:
@@ -36,8 +35,7 @@ class GenericLoader(Loader):
         self.conf = conf
         self._callback_func = self.conf.get(CALLBACK_FUNCTION, log_call_back)
 
-    def load(self, record):
-        # type: (Optional[Any]) -> None
+    def load(self, record: Optional[Any]) -> None:
         """
         Write record to function
         :param record:
@@ -48,10 +46,8 @@ class GenericLoader(Loader):
 
         self._callback_func(record)
 
-    def close(self):
-        # type: () -> None
+    def close(self) -> None:
         pass
 
-    def get_scope(self):
-        # type: () -> str
+    def get_scope(self) -> str:
         return "loader.generic"
